@@ -1,9 +1,7 @@
 library(data.table)
-library(plyr)
-
 data("MOD13A1")
 
-dt <- tidy_MOD13.gee(MOD13A1$dt)
+dt <- tidy_MOD13(MOD13A1$dt)
 st <- MOD13A1$st
 
 sitename <- dt$site[1]
