@@ -9,10 +9,8 @@ param = listk(
     INPUT,
     rFUN = smooth_wWHIT, wFUN = wBisquare, iters = 2,
     lambda,
-    IsPlot = IsPlot, plotdat = d,
-    south = sp$lat[1] < 0,
-    rymin_less = 0.6, ypeak_min = ypeak_min,
-    max_MaxPeaksperyear =2.5, max_MinPeaksperyear = 3.5
+    rtrough_max = 0.6, ypeak_min = ypeak_min,
+    MaxPeaksPerYear =2.5, MaxTroughsPerYear = 3.5
 )
 
 
